<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Amenity;
use App\Models\Article;
use App\Models\Property;
use App\Models\PropertyImage;
use App\Models\User;
use App\Models\VehicleCategory;
use App\Models\VehicleType;
use App\Models\PropertyKind;
use App\Models\YoutubeVideo;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Validator;
use App\Models\PropertyVideo;
class AdminController extends Controller
{
    public function dashboard(Request $request)
    {

        $premiumProperty = DB::table('property')->where("is_premium", 1)->get();
        $otherProperty = DB::table('property')->where("is_premium", 0)->get();

        $data['premiumPropertyCount'] = count($premiumProperty);
        $data['otherPropertyCount'] = count($otherProperty);
        return view('admin.dashboard', compact('data'));
    }

    public function propertyList(Request $request)
    {
        $data["property"] = Property::orderBy('property_created_date', 'DESC')->get();
        // dd($data);
        return view('admin.property_list', compact('data'));
    }

    public function propertyAddEdit(Request $request, $id)
    {
        $data["pageTitle"] = "";
        $data["id"] = $id;

        $data['category_types'] = VehicleType::where('vehicle_status', 1)->whereNotIn('vehicle_type_id', [1])->get();
        $data['property_types'] = VehicleCategory::orderBy('vehicle_category_id', 'DESC')->distinct()->get();
        $data['amenities_list'] = Amenity::where('status', 1)->get();
        $data['images'] = [];
        if ($id == 0) {
            $data["pageTitle"] = "Add New Property";
        } else {
            $data["pageTitle"] = "Update Property";
            $data['data'] = Property::where("property_id", $id)->first();
            $data['images'] = PropertyImage::orderBy('sort_order', 'ASC')->where("property_id", $id)->distinct()->get();
        }
        // dd($data);
        return view('admin.property_add_edit', compact('data'));
    }

    public function saveProperty(Request $request)
    {   
        $chk_property_custom_url = $this->chk_property_custom_url($request);

        if($chk_property_custom_url){
            return response()->json(['success' => 2, 'message' => 'This custom url already exis']);
        }
        
        // dd($request);
        if ($request->id == 0) {
            $property = new Property;
            $property->property_status = 1;
            $property->property_created_date = date("Y-m-d H:i:s");
            $message = "Property saved successfully";
        } else {
            $property = Property::where("property_id", $request->id)->first();
            $property->property_status = $request->status;
            $message = "Property saved successfully";
        }
        // $checkval = $request->bedroom_maids ? 1 : 0;
        // dd($checkval);
        $lat = "";
        $long = "";
        if ($request->location) {
            $location = explode(",", $request->location);
            $lat = $location[0];
            $long = $location[1];
        }

        $property->property_type = $request->property_type;
        $property->property_name = $request->property_name;
        $property->property_bedroom = $request->property_bedroom;
        $property->property_bathroom = $request->property_bathroom;
        $property->property_sqft = $request->property_sqft;
        $property->property_desc = $request->property_desc;
        $property->property_amenities = $request->amenities ? implode(',', $request->amenities) : "";
        $property->property_location = ($request->txt_location) ? $request->txt_location : '';
        $property->property_language_code = 1;
        $property->latitude = $lat;
        $property->longitude = $long;
        $property->category_type = $request->category_type;
        $property->bedroom_maids = $request->bedroom_maids ? 1 : 0;
        $property->is_premium = 1; //$request->is_premium;
        $property->is_sale = $request->is_sale ? 1 : 0;
        $property->service_charges = $request->service_charges;
        $property->completion_level = $request->completion_level;
        $property->featured = $request->featured ? 1 : 0;
        $property->rent_type = $request->category_type == 2 ? $request->rent_type : "";
        $property->property_price = $request->property_price;
        $property->property_custom_url = $request->property_custom_url;
        $property->property_meta_title = $request->property_meta_title;
        $property->property_meta_keyword = $request->property_meta_keyword;
        $property->property_meta_description = $request->property_meta_description;
        $property->save();

        DB::table('property_amenities')->where('property_id', $property->property_id)->delete();
        foreach ($request->amenities as $am) {
            $a_ins['amenities_id'] = $am;
            $a_ins['property_id'] = $property->property_id;
            DB::table('property_amenities')->insert($a_ins);
        }
        return response()->json(['success' => 1, 'message' => $message]);
    }

    public function deleteProperty(Request $request)
    {
        $record = Property::find($request->id);
        if ($record) {
            $record->delete();
            return response()->json(['success' => true, 'message' => "Record has been delete successfully"]);
        }
        return response()->json(['success' => false, 'message' => "Something went wrong."]);
    }

    public function properImages(Request $request)
    {
        // dd($request);
        $images = PropertyImage::orderBy('sort_order', 'ASC')->where("property_id", $request->id)->distinct()->get();
        // dd($images);
        $imageArr = [];
        if ($images) {
            foreach ($images as $image) {
                $tempArray = [];
                $tempArray['property_id'] = $image->property_id;
                $tempArray['property_images_id'] = $image->property_images_id;
                $tempArray['property_images_name'] = $image->property_images_name;
                $tempArray['property_images_path'] = $image->property_images_name;
                $tempArray['sort_order'] = $image->sort_order;
                array_push($imageArr, $tempArray);

            }
            return response()->json(['success' => true, 'images' => $imageArr, 'message' => "Images loaded successfully"]);
        }

        return response()->json(['success' => true, 'images' => $imageArr, 'message' => "Images not found"]);
    }

    public function properDeleteImage(Request $request)
    {
        // dd($request);
        $record = PropertyImage::where("property_images_id", $request->id);
        if ($record) {
            $record->delete();
            return response()->json(['success' => true, 'message' => "Image has been delete successfully"]);
        }
        return response()->json(['success' => false, 'message' => "Something went wrong."]);
    }

    public function imageOrderChange(Request $request)
    {
        // dd($request);

        foreach ($request->image_sort_order as $id => $val) {
            $record = PropertyImage::where("property_images_id", $id)->first();
            // dd($record);
            if ($record) {
                $record->sort_order = $val;
                $record->save();
            }
        }
        $imageArr = [];
        $images = PropertyImage::orderBy('sort_order', 'ASC')->where("property_id", $request->img_property_id)->distinct()->get();
        if ($images) {
            foreach ($images as $image) {
                $tempArray = [];
                $tempArray['property_id'] = $image->property_id;
                $tempArray['property_images_id'] = $image->property_images_id;
                $tempArray['property_images_name'] = $image->property_images_name;
                $tempArray['property_images_path'] = $image->property_images_name;
                $tempArray['sort_order'] = $image->sort_order;
                array_push($imageArr, $tempArray);
            }
        }
        return response()->json(['success' => true, 'message' => "Order changed successfully", 'images' => $imageArr]);
    }

    public function propertyImageUpload(Request $request)
    {
        // dd($request);
        $rules = [
            'images.*' => 'dimensions:min_width=705,min_height=465',
        ];
        $validator = Validator::make($request->all(), $rules,
            [
                'images.*.dimensions' => 'Image minimum dimension should be 705X465',
            ]
        );
        $errors = '';
        $imageArr = [];
        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        } else {

            foreach ($request->images as $image) {
                $imageName = time() . preg_replace('/[^a-zA-Z0-9_.]/', '_', $image->getClientOriginalName());
                $image->move(public_path('property/images'), $imageName);
                $record = new PropertyImage;
                $record->property_id = $request->property_id;
                $record->sort_order = $request->image_sort_order;
                $record->property_images_name = $imageName;
                $record->save();
            }
            $status = "1";
            $message = "Successfully uploaded";

            $images = PropertyImage::orderBy('sort_order', 'ASC')->where("property_id", $request->property_id)->distinct()->get();

            if ($images) {
                foreach ($images as $image) {
                    $tempArray = [];
                    $tempArray['property_id'] = $image->property_id;
                    $tempArray['property_images_id'] = $image->property_images_id;
                    $tempArray['property_images_name'] = $image->property_images_name;
                    $tempArray['property_images_path'] = $image->property_images_name;
                    $tempArray['sort_order'] = $image->sort_order;
                    array_push($imageArr, $tempArray);

                }
            }
        }
        return response()->json(['status' => $status, 'message' => $message, 'errors' => $errors, 'images' => $imageArr]);
        // return redirect()->route("admin.property.list");
    }

    public function amenitiesList(Request $request)
    {
        $data["amenitiesList"] = DB::table('amenities')->distinct()->get();
        return view('admin.amenities_list', compact('data'));
    }

    public function amenitiesAddEdit(Request $request, $id)
    {
        $data["pageTitle"] = "";
        $data["id"] = $id;
        if ($id == 0) {
            $data["pageTitle"] = "Add New Amenities";
        } else {
            $data["pageTitle"] = "Update Amenities";
            $data['data'] = Amenity::where("amenities_id", $id)->first();
        }
        return view('admin.amenities_add_edit', compact('data'));
    }

    public function saveAmenities(Request $request)
    {
        // dd($request);
        if ($request->id == 0) {
            $amenities = new Amenity;
            $amenities->amenities_name = $request->amenities_name;
            $amenities->status = 1;
            $amenities->created_date = date("Y-m-d H:i:s");
            $amenities->save();
            $message = "Amenities saved successfully";
        } else {
            $amenities = Amenity::where("amenities_id", $request->id)->first();
            $amenities->amenities_name = $request->amenities_name;
            $amenities->status = $request->status;
            $amenities->save();
            $message = "Amenities saved successfully";
        }

        return response()->json(['success' => true, 'message' => $message]);

    }
    public function deletAmenity(Request $request)
    {
        $record = Amenity::find($request->id);
        if ($record) {
            $record->delete();
            return response()->json(['success' => true, 'message' => "Record has been delete successfully"]);
        }
        return response()->json(['success' => false, 'message' => "Something went wrong."]);
    }

    public function propertyTypeList(Request $request)
    {
        $data["propertyType"] = VehicleCategory::distinct()->orderBy('vehicle_category_id', 'DESC')->get();
        // dd($data["propertyType"]);
        return view('admin.property_type_list', compact('data'));
    }

    public function propertyTypeAddEdit(Request $request, $id)
    {
        $data["pageTitle"] = "";
        $data["id"] = $id;
        if ($id == 0) {
            $data["pageTitle"] = "Add Property Type";
        } else {
            $data["pageTitle"] = "Edit Property Type";
            $data['data'] = VehicleCategory::where("vehicle_category_id", $id)->first();
        }
        return view('admin.property_type_add_edit', compact('data'));
    }

    public function savePropertyType(Request $request)
    {
        // dd($request);
        if ($request->id == 0) {
            $vehicleType = new VehicleCategory;
            $vehicleType->vehicle_category_status = 1;
            $vehicleType->vehicle_category_created_at = date("Y-m-d H:i:s");

            $message = "Proerpty type saved successfully";
        } else {
            $vehicleType = VehicleCategory::where("vehicle_category_id", $request->id)->first();
            $vehicleType->vehicle_category_status = $request->vehicle_category_status;
            $message = "Proerpty type saved successfully";
        }

        $vehicleType->vehicle_category_name = $request->vehicle_category_name;
        $vehicleType->vehicle_category_parent_id = 0;
        $vehicleType->vehicle_category_language_code = 1;
        $vehicleType->vehicle_type_id = 0;
        $vehicleType->show_in_home = $request->show_in_home ? 1 : 0;
        if ($file = $request->file("image")) {
            $dir = public_path('property_type');
            $file_name = time() . $file->getClientOriginalName();
            $file->move($dir, $file_name);
            $vehicleType->image = $file_name;
        }
        $vehicleType->save();

        return response()->json(['success' => true, 'message' => $message]);

    }

    public function deletePropertyType(Request $request)
    {
        $record = VehicleCategory::find($request->id);
        if ($record) {
            $record->delete();
            return response()->json(['success' => true, 'message' => "Record has been delete successfully"]);
        }
        return response()->json(['success' => false, 'message' => "Something went wrong."]);
    }


    public function propertyKindList(Request $request)
    {
        $data["datamain"] = PropertyKind::distinct()->orderBy('id', 'DESC')->get();
        // dd($data["propertyType"]);
        return view('admin.property_kind_list', compact('data'));
    }

    public function propertyKindAddEdit(Request $request, $id)
    {
        $data["pageTitle"] = "";
        $data["id"] = $id;
        if ($id == 0) {
            $data["pageTitle"] = "Add Property Kind";
        } else {
            $data["pageTitle"] = "Edit Property Kind";
            $data['data'] = PropertyKind::where("id", $id)->first();
        }
        return view('admin.property_kind_add_edit', compact('data'));
    }

    public function savePropertyKind(Request $request)
    {
     
        if ($request->id == 0) {
            $datains = new PropertyKind;
            $datains->created_at = gmdate('Y-m-d H:i:s') ;

            $message = "Proerpty Kind saved successfully";
        } else {
            $datains = PropertyKind::where("id", $request->id)->first();
            $datains->updated_at = gmdate('Y-m-d H:i:s') ;
            $message = "Proerpty Kind saved successfully";
        }

        $datains->show_in_home = $request->show_in_home ? 1 : 0;
        $datains->kind_name = $request->kind_name;
        
        if ($file = $request->file("image")) {
            $dir = public_path('property_kind');
            $file_name = time() . $file->getClientOriginalName();
            $file->move($dir, $file_name);
            $datains->image = $file_name;
        }
        $datains->save();

        return response()->json(['success' => true, 'message' => $message]);

    }

    public function deletePropertyKind(Request $request)
    {
        $record = PropertyKind::find($request->id);
        if ($record) {
            $record->delete();
            return response()->json(['success' => true, 'message' => "Record has been delete successfully"]);
        }
        return response()->json(['success' => false, 'message' => "Something went wrong."]);
    }

    public function videoList(Request $request)
    {
        $data["videoList"] = YoutubeVideo::distinct()->orderBy('video_id', 'DESC')->get();
        return view('admin.video_list', compact('data'));
    }

    public function videoAddEdit(Request $request, $id)
    {
        $data["pageTitle"] = "";
        $data["id"] = $id;
        if ($id == 0) {
            $data["pageTitle"] = "Add New Video";
        } else {
            $data["pageTitle"] = "Update Video";
            $data['data'] = YoutubeVideo::where("video_id", $id)->first();
        }
        return view('admin.video_add_edit', compact('data'));
    }

    public function saveVideoType(Request $request)
    {
        if ($request->id == 0) {
            $video = new YoutubeVideo;
            $video->status = 1;
            $video->created_date = date("Y-m-d H:i:s");
            $message = "Video saved successfully";
        } else {
            $video = YoutubeVideo::where("video_id", $request->id)->first();
            $video->status = $request->status;
            $message = "Video saved successfully";
        }
        $video->youtube_video_link = $request->youtube_video_link;
        $video->youtube_video_id = $request->youtube_video_id;
        $video->save();
        return response()->json(['success' => true, 'message' => $message]);
    }

    public function deleteVideo(Request $request)
    {
        $record = YoutubeVideo::find($request->id);
        if ($record) {
            $record->delete();
            return response()->json(['success' => true, 'message' => "Record has been delete successfully"]);
        }
        return response()->json(['success' => false, 'message' => "Something went wrong."]);
    }

    public function subscribeEmailList(Request $request)
    {

        $data["subscriberList"] = DB::table('subscribe_email')->orderBy('created_date', 'DESC')->get();
        return view('admin.subscribe_email_list', compact('data'));
    }

    public function contentList(Request $request)
    {
        $content = DB::table('articles AS a')
            ->join('articles AS a2', 'a2.articles_id', '=', 'a.articles_id')
            ->join('article_type AS a3', 'a3.article_type_id', '=', 'a.articles_type_id')
            ->where('a.articles_language_code', 1)
            ->where('a2.articles_language_code', 1)
            ->groupBy('a3.article_type_desc', 'a.articles_type_id', 'a.articles_status', 'a.articles_created_date', 'a.articles_id')
            ->orderBy('a.articles_id', 'desc')
            ->get(['a3.article_type_desc', 'a.articles_type_id', 'a.articles_status', 'a.articles_created_date', 'a.articles_id']);
        $data["content"] = $content;
        // dd($data);
        return view('admin.content_list', compact('data'));
    }

    public function contentAddEdit(Request $request, $id)
    {
        $data["pageTitle"] = "";
        $data["id"] = $id;
        if ($id == 0) {
            $data["pageTitle"] = "Add New Content";
        } else {
            $data["pageTitle"] = "Update Content";
            $data['data'] = Article::where("articles_id", $id)->first();
        }
        $data['articleTypes'] = DB::table('article_type')->get();
        // dd($data);
        return view('admin.content_add_edit', compact('data'));
    }

    public function saveContent(Request $request)
    {
        // dd($request);
        if ($request->id == 0) {
            $article = new Article;
            $article->articles_status = 1;
            $article->articles_created_date = date("Y-m-d H:i:s");
            $message = "Article saved successfully";
        } else {
            $article = Article::where("articles_id", $request->id)->first();
            $message = "Article saved successfully";
        }

        $article->articles_language_code = 1;
        $article->articles_type_id = $request->articles_type_id;
        $article->articles_desc = $request->articles_desc;
        $article->meta_title = $request->meta_title;
        $article->meta_keyword = $request->meta_keyword;
        $article->meta_description = $request->meta_description;
        $article->save();

        return response()->json(['success' => true, 'message' => $message]);
    }

    public function deleteContent(Request $request)
    {
        $record = Article::find($request->id);
        if ($record) {
            $record->delete();
            return response()->json(['success' => true, 'message' => "Record has been delete successfully"]);
        }
        return response()->json(['success' => false, 'message' => "Something went wrong."]);
    }

    public function changePassword(Request $request)
    {

        return view('admin.change_password');
    }

    public function changePasswordSave(Request $request)
    {

        $current_password = Auth::User()->admin_user_password;
        if (Hash::check($request->old_password, $current_password)) {
            $user = User::find(Auth::User()->admin_user_id);
            $user->admin_user_password = Hash::make($request->new_password);
            $user->save();
            return response()->json(['success' => true, 'message' => "Password has been changed successfully"]);
        } else {
            return response()->json(['success' => false, 'message' => "Incorrect current password"]);
        }
    }

    public function logout(Request $request)
    {
        Auth::logout();
        return redirect()->route('admin.login');
    }
    public function valuation()
    {
        $data["list"] = DB::table('valuations')->orderBy('created_at', 'DESC')->get();
        return view('admin.valuation_list', compact('data'));
    }
    public function delete_valuation(Request $request)
    {
        DB::table('valuation_docs')->where("valuation_id", $request->id)->delete();
        DB::table('valuations')->where("id", $request->id)->delete();
        return response()->json(['success' => true, 'message' => "Record has been deleted successfully"]);
    }
    public function view_valuation($id)
    {
        $valuation = DB::table('valuations')->where("id", $id)->first();
        if (!$valuation) {
            abort(404);
        }
        $images = DB::table('valuation_docs')->where(["valuation_id" => $id, 'type' => 1])->get();
        $docs = DB::table('valuation_docs')->where(["valuation_id" => $id, 'type' => 2])->get();
        return view('admin.view_valuation', compact('valuation', 'images', 'docs'));
    }
    public function contact_us()
    {
        $data["list"] = DB::table('contact_us')->orderBy('date', 'DESC')->get();
        return view('admin.contact_us_list', compact('data'));
    }
    public function delete_contact_us(Request $request)
    {
        DB::table('contact_us')->where("id", $request->id)->delete();
        return response()->json(['success' => true, 'message' => "Record has been deleted successfully"]);
    }

    public function enquiry()
    {
        $data["list"] = DB::table('property_enquiries')->orderBy('created_at', 'DESC')->get();
        return view('admin.enquiry_list', compact('data'));
    }
    public function delete_enquiry(Request $request)
    {
        DB::table('property_enquiries')->where("id", $request->id)->delete();
        return response()->json(['success' => true, 'message' => "Record has been deleted successfully"]);
    }
    public function view_enquiry($id)
    {
        $enq = DB::table('property_enquiries')->select('property_enquiries.*', 'property_name')->join('property', 'property.property_id', '=', 'property_enquiries.property_id')->where("id", $id)->first();
        if (!$enq) {
            abort(404);
        }
        return view('admin.view_enquiry', compact('enq'));
    }

    public function verify_property($id)
    {
        $status = 0;
        $message = "";
        $property = Property::find($id);
        if ($property) {
            if ($property->verified == 1) {
                $verified = 0;
            } else {
                $verified = 1;
            }
            $ret = Property::where('property_id', $id)->update(['verified' => $verified]);
            if ($ret) {
                $status = 1;
                $message = "Successfully updated";
            } else {
                $message = "Faild to update";
            }
        } else {
            $message = "No details found";
        }
        echo json_encode(['status' => $status, 'message' => $message]);
    }
    public function propertySort(Request $request)
    {
        if ($request->ajax()) {
            $status = 0;
            $message = '';

            $items = $request->items;
            $items = explode(",", $items);
            $sorted = Property::sort_item($items);
            if ($sorted) {
                $status = 1;
            }

            echo json_encode(['status' => $status, 'message' => $message]);

        } else {
            $page_heading = "Sort Categories";

            $list = Property::select('property_id as id', 'property_name as name')->where(['featured' => 1, 'property_status' => 1])->orderBy('sort_order', 'asc')->orderBy('property_created_date', 'DESC')->get();

            return view("admin.sort", compact('page_heading', 'list'));
        }
    }
    
    public function properVideos(Request $request){
        // dd($request);
        $images = PropertyVideo::orderBy('sort_order','ASC')->where("property_id", $request->id)->distinct()->get();
        // dd($images);
        $imageArr = [];
        if($images){            
            foreach($images as $image){
                $tempArray = [];
                $tempArray['property_id'] = $image->property_id;
                $tempArray['property_video_id'] = $image->property_video_id;
                if($image->property_video_name!="") {
                    $tempArray['property_video_name'] = $image->property_video_name;
                } else {
                     $tempArray['property_video_name'] = $image->property_video_url;
                }
                $tempArray['property_video_url'] = (string)$image->property_video_url;
                $tempArray['sort_order'] = $image->sort_order;
                $tempArray['property_image_path'] = $image->property_image_name;
                array_push($imageArr, $tempArray);

            }
            return response()->json(['success' => true, 'images' => $imageArr, 'message' => "Images loaded successfully"]);
        }
        
        return response()->json(['success' => true, 'images' => $imageArr, 'message' => "Images not found"]);
    }
    public function properDeleteVideo(Request $request){
        // dd($request);
        $record = PropertyVideo::where("property_video_id", $request->id);
        if($record){
            $record->delete();
            return response()->json(['success' => true, 'message' => "Video has been delete successfully"]);
        } 
        return response()->json(['success' => false, 'message' => "Something went wrong."]);
    }
    public function propertyVideoUpload(Request $request){
        // dd($request);
         $record = new PropertyVideo;
        $record->property_id = $request->property_id;
        $record->sort_order = $request->video_sort_order;
         if(!empty($request->video)) {
            $imageName = time().'.'.$request->video->extension();  
            $request->video->move(public_path('property/videos'), $imageName);
            $record->property_video_name = $imageName;
        }
        if(!empty($request->image)) {
            $imageName = time().'.'.$request->image->extension();  
            $request->image->move(public_path('property/images'), $imageName);
            $record->property_image_name = $imageName;
        }
        // dd($imageName);
       
        $record->property_video_url = $request->video_url;
        
        
        $record->save();
        return redirect()->route("admin.property.list");
    }
    
    public function videoOrderChange(Request $request){
        // dd($request);

        foreach($request->image_sort_order as $id => $val){
            $record = PropertyVideo::where("property_video_id", $id)->first();
            // dd($record);
            if($record){
                $record->sort_order = $val;
                $record->save();
            }
        }
        return response()->json(['success' => true, 'message' => "Order changed successfully"]);
    }
    
    
    public function chk_property_custom_url($request){

        if ($request->id == 0) {

            $chk_property = Property::where("property_custom_url", $request->property_custom_url)->get()->toArray();

        }
        else
        {
            $chk_property = Property::whereNotIn("property_id", [$request->id])->where("property_custom_url", $request->property_custom_url)->get()->toArray();
        }

        return $chk_property;

    }

}
