@extends('admin.layouts.master')
@section('headerFiles')
    <link rel="stylesheet" type="text/css" href="{{ asset('admin-assets/plugins/table/datatable/datatables.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ asset('admin-assets/plugins/table/datatable/custom_dt_zero_config.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ asset('admin-assets/plugins/jqvalidation/custom-jqBootstrapValidation.css') }}">
    <link href="{{ asset('admin-assets/plugins/notification/toastr/toastr.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ asset('admin-assets/plugins/editors/tinymce/stylesheet.css') }}" rel="stylesheet" type="text/css" />
    <!-- END GLOBAL MANDATORY STYLES -->    
    <style type="text/css">
        .error{
            color: red;
            display: block;
        }

    </style>
@endsection

@section('content')

<div class="container">
    <div class="page-header">
        <div class="page-title">
            <h3>{{ $data["pageTitle"] }}</h3>
        </div>
    </div>

    <div class="row layout-spacing ">

        <div class="col-xl-12 col-lg-12 col-md-12 col-sm-12 col-12  layout-spacing">
            <div class="statbox widget box box-shadow">                
                <div class="widget-content widget-content-area">
                    <form method="post" class="form-validate" method="post">
                        @csrf

                        <div class="form-group">
                            <label for="t-text">Article Type</label>                                            
                            <select class="custom-select mb-4" name="articles_type_id" id="articles_type_id" required>
                                <option value="">Selct Article Type</option>
                                @foreach ($data['articleTypes'] as $articleType)
                                <option value="{{ $articleType->article_type_id }}" {{ $data["id"] != 0 && $data["data"]->articles_id == $articleType->article_type_id ? "selected" : ""}} >{{ $articleType->article_type_desc }}</option>    
                                @endforeach
                                
                            </select>                            
                        </div>
                        <div class="form-group">
                            <label for="t-text">Article English</label>
                            <textarea id="articles_desc" name="articles_desc" class="form-control">{{ $data["id"] != 0 ? $data["data"]->articles_desc : "" }}</textarea>
                        </div>
                        <div class="form-group">
                            <label for="t-text">Meta Title</label>
                            <input type="text" name="meta_title" id="meta_title" value="{{ $data["id"] != 0 ? $data["data"]->meta_title : ""}}" class="form-control" placeholder="Enter meta title">
                        </div>
                        <div class="form-group">
                            <label for="t-text">Meta Keyword</label>
                            <input type="text" name="meta_keyword" id="meta_keyword" value="{{ $data["id"] != 0 ? $data["data"]->meta_keyword : ""}}" class="form-control" placeholder="Enter meta keywords">
                        </div>
                        <div class="form-group">
                            <label for="t-text">Meta Description</label>
                            <input type="text" name="meta_description" id="meta_description" value="{{ $data["id"] != 0 ? $data["data"]->meta_description : ""}}" class="form-control" placeholder="Enter meta description">
                        </div>
                        <div class="form-group">
                            <input type="submit" name="txt" class="mt-4 btn btn-button-7">
                            <input type="hidden" name="id" id="id" value="{{ $data["id"] }}" >
                        </div>
                    </form>
                </div>
            </div>
        </div>
        
    </div>

</div>

@endsection

@section('footerJs')
<script src="{{ asset('admin-assets/plugins/jqvalidation/jqBootstrapValidation-1.3.7.min.js') }}"></script>
<script src="{{ asset('admin-assets/plugins/jqvalidation/jqBootstrapValidation-1.3.7.min.js') }}"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery-validate/1.19.3/jquery.validate.js"></script>
<script src="{{ asset('admin-assets/plugins/notification/toastr/toastr.min.js') }}"></script>
<script src="{{ asset('admin-assets/plugins/editors/tinymce/tinymce.min.js') }}"></script>
<script src="{{ asset('admin-assets/plugins/editors/tinymce/editor_tinymce.js') }}"></script>
<script>
    tinymce.init({
        selector: '#articles_desc'
      });
    // Toaster options
    toastr.options = {
        "closeButton": false,
        "debug": false,
        "newestOnTop": false,
        "progressBar": false,
        "rtl": false,
        "positionClass": "toast-top-right",
        "preventDuplicates": false,
        "onclick": null,
        "showDuration": 300,
        "hideDuration": 1000,
        "timeOut": 1000,
        "extendedTimeOut": 1000,
        "showEasing": "swing",
        "hideEasing": "linear",
        "showMethod": "fadeIn",
        "hideMethod": "fadeOut"
    }

    $(".form-validate").submit(function(e) {
        e.preventDefault();
    }).validate({
        rules: {           
            articles_type_id: "required"            
        },
        messages: {            
            articles_type_id: "Please select article type"
        },
        submitHandler: function(form) { 
            $.ajax({
                type:'POST',
                url: "{{ route("admin.content.add_edit_save")}}",
                data:{
                    "_token" : "{{ csrf_token() }}",
                    "articles_type_id" : $("#articles_type_id").val(),
                    "articles_desc" : tinymce.get("articles_desc").getContent(),
                    "meta_title" : $("#meta_title").val(),
                    "meta_keyword" : $("#meta_keyword").val(),
                    "meta_description" : $("#meta_description").val(),
                    "id" : $("#id").val(),
                },
                // data: $('.form-validate').serialize()+"&articles_desc="+tinymce.get("articles_desc").getContent(),
                success: function(response) {
                    if(response.success){
                        toastr["success"](response.message);
                        setTimeout(function(){ 
                            window.location.href = "{{ route("admin.content.list")}}";
                        }, 2000);                        
                    } else {
                        toastr["error"](response.message);
                    }
                }            
            });
        }
    });
</script>

@endsection